==> xrpl-plugin-0.2.1.tar.gz: xrpl-plugin-0.2.1/xrpl_plugin/rippled/src/test/basics/DetectCrash_test.cpp <==
//------------------------------------------------------------------------------
/*
    This file is part of rippled: https://github.com/ripple/rippled
    Copyright (c) 2012, 2013 Ripple Labs Inc.

    Permission to use, copy, modify, and/or distribute this software for any
    purpose  with  or without fee is hereby granted, provided that the above
    copyright notice and this permission notice appear in all copies.

    THE  SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
    WITH  REGARD  TO  THIS  SOFTWARE  INCLUDING  ALL  IMPLIED  WARRANTIES  OF
    MERCHANTABILITY  AND  FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
    ANY  SPECIAL ,  DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
    WHATSOEVER  RESULTING  FROM  LOSS  OF USE, DATA OR PROFITS, WHETHER IN AN
    ACTION  OF  CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
    OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/
//==============================================================================

#include <ripple/beast/unit_test/suite.hpp>

#include <exception>

namespace ripple {
namespace test {

struct DetectCrash_test : public beast::unit_test::suite
{
    void
    testDetectCrash()
    {
        testcase("Detect Crash");
        // Kill the process. This is used to test that the multi-process
        // unit test will correctly report the crash.
        std::terminate();
    }
    void
    run() override
    {
        testDetectCrash();
    }
};

BEAST_DEFINE_TESTSUITE_MANUAL(DetectCrash, unit_test, beast);

}  // namespace test
}  // namespace ripple

==> xrpl-plugin-0.2.2.tar.gz: xrpl-plugin-0.2.2/xrpl_plugin/rippled/src/test/basics/DetectCrash_test.cpp <==
//------------------------------------------------------------------------------
/*
    This file is part of rippled: https://github.com/ripple/rippled
    Copyright (c) 2012, 2013 Ripple Labs Inc.

    Permission to use, copy, modify, and/or distribute this software for any
    purpose  with  or without fee is hereby granted, provided that the above
    copyright notice and this permission notice appear in all copies.

    THE  SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
    WITH  REGARD  TO  THIS  SOFTWARE  INCLUDING  ALL  IMPLIED  WARRANTIES  OF
    MERCHANTABILITY  AND  FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
    ANY  SPECIAL ,  DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
    WHATSOEVER  RESULTING  FROM  LOSS  OF USE, DATA OR PROFITS, WHETHER IN AN
    ACTION  OF  CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
    OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/
//==============================================================================

#include <ripple/beast/unit_test/suite.h>

#include <exception>

namespace ripple {
namespace test {

struct DetectCrash_test : public beast::unit_test::suite
{
    void
    testDetectCrash()
    {
        testcase("Detect Crash");
        // Kill the process. This is used to test that the multi-process
        // unit test will correctly report the crash.
        std::terminate();
    }
    void
    run() override
    {
        testDetectCrash();
    }
};

BEAST_DEFINE_TESTSUITE_MANUAL(DetectCrash, unit_test, beast);

}  // namespace test
}  // namespace ripple
